@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import os.path
 import time
 from contextlib import ExitStack, contextmanager
 from enum import unique
@@ -41,7 +42,7 @@ class Config(
     trigger_stereo render_stereo
     """,
 ):
-    """ Default values indicate optional attributes. """
+    """Default values indicate optional attributes."""
 
     master_audio: Optional[str]
     begin_time: float = with_units("s", default=0)
@@ -63,11 +64,11 @@ class Config(
 
     # Both before_* functions should be idempotent, AKA calling twice does no harm.
     def before_preview(self) -> None:
-        """ Called *once* before preview. Does nothing. """
+        """Called *once* before preview. Does nothing."""
         self.render.before_preview()
 
     def before_record(self) -> None:
-        """ Called *once* before recording video. Force high-quality rendering. """
+        """Called *once* before recording video. Force high-quality rendering."""
         self.render_subfps = 1
         self.trigger_subsampling = 1
         self.render_subsampling = 1
@@ -91,7 +92,7 @@ class Config(
     ffmpeg_cli: FFmpegOutputConfig = attr.ib(factory=lambda: FFmpegOutputConfig(None))
 
     def get_ffmpeg_cfg(self, video_path: str) -> FFmpegOutputConfig:
-        return attr.evolve(self.ffmpeg_cli, path=video_path)
+        return attr.evolve(self.ffmpeg_cli, path=os.path.abspath(video_path))
 
     benchmark_mode: BenchmarkMode = attr.ib(
         BenchmarkMode.NONE, converter=BenchmarkMode.by_name
@@ -102,7 +103,7 @@ _FPS = 60  # f_s
 
 
 def template_config(**kwargs) -> Config:
-    """ Default template values do NOT indicate optional attributes. """
+    """Default template values do NOT indicate optional attributes."""
     cfg = Config(
         master_audio="",
         fps=_FPS,
@@ -149,7 +150,7 @@ class Arguments:
 
 class CorrScope:
     def __init__(self, cfg: Config, arg: Arguments):
-        """ cfg is mutated!
+        """cfg is mutated!
         Recording config is triggered if any FFmpegOutputConfig is found.
         Preview mode is triggered if all outputs are FFplay or others.
         """
