@@ -166,16 +166,25 @@ class MainWindow(qw.QMainWindow, Ui_MainWindow):
     - Otherwise empty string.
         - self.get_save_filename() calls cli.get_file_stem().
 
-    CLI filename is the same,
-    but defaults to "corrscope.{yaml, mp4}" instead of empty string.
+    CLI YAML filename is the same,
+    but defaults to "corrscope.yaml" instead of empty string.
     - cli._get_file_name() calls cli.get_file_stem().
+
+    CLI video filename is explicitly specified by the user.
     """
 
     def __init__(self, cfg_or_path: Union[Config, Path]):
         super().__init__()
 
         # Load settings.
-        self.pref = gp.load_prefs()
+        prefs_error = None
+        try:
+            self.pref = gp.load_prefs()
+            if not isinstance(self.pref, gp.GlobalPrefs):
+                raise TypeError(f"prefs.yaml contains wrong type {type(self.pref)}")
+        except Exception as e:
+            prefs_error = e
+            self.pref = gp.GlobalPrefs()
 
         # Load UI.
         self.setupUi(self)  # sets windowTitle
@@ -237,6 +246,12 @@ class MainWindow(qw.QMainWindow, Ui_MainWindow):
 
         self.show()
 
+        if prefs_error is not None:
+            TracebackDialog(self).showMessage(
+                "Warning: failed to load global preferences, resetting to default.\n"
+                + format_stack_trace(prefs_error)
+            )
+
     _cfg_path: Optional[Path]
 
     # Whether document is dirty, changed, has unsaved changes
@@ -490,7 +505,7 @@ class MainWindow(qw.QMainWindow, Ui_MainWindow):
             return False
 
     def on_action_preview(self):
-        """ Launch CorrScope and ffplay. """
+        """Launch CorrScope and ffplay."""
         if self.corr_thread is not None:
             error_msg = self.tr("Cannot preview, another {} is active").format(
                 self.preview_or_render
@@ -502,7 +517,7 @@ class MainWindow(qw.QMainWindow, Ui_MainWindow):
         self.play_thread(outputs, PreviewOrRender.preview, dlg=None)
 
     def on_action_render(self):
-        """ Get file name. Then show a progress dialog while rendering to file. """
+        """Get file name. Then show a progress dialog while rendering to file."""
         if self.corr_thread is not None:
             error_msg = self.tr("Cannot render to file, another {} is active").format(
                 self.preview_or_render
@@ -512,7 +527,12 @@ class MainWindow(qw.QMainWindow, Ui_MainWindow):
 
         # Name and extension (no folder).
         video_filename = self.get_save_filename(cli.VIDEO_NAME)
-        filters = ["MP4 files (*.mp4)", "All files (*)"]
+        filters = [
+            "MP4 files (*.mp4)",
+            "Matroska files (*.mkv)",
+            "WebM files (*.webm)",
+            "All files (*)",
+        ]
 
         # Points to either `file_dir` or `render_dir`.
         # Folder is obtained from `dir_ref`.
@@ -750,7 +770,7 @@ class CorrProgressDialog(qw.QProgressDialog):
 def run_on_ui_thread(
     bound_slot: MethodType, types: Tuple[type, ...]
 ) -> Callable[..., None]:
-    """ Runs an object's slot on the object's own thread.
+    """Runs an object's slot on the object's own thread.
     It's terrible code but it works (as long as the slot has no return value).
     """
     qmo = qc.QMetaObject
@@ -1000,13 +1020,13 @@ nope = qc.QVariant()
 
 
 class ChannelModel(qc.QAbstractTableModel):
-    """ Design based off
+    """Design based off
     https://doc.qt.io/qt-5/model-view-programming.html#a-read-only-example-model and
     https://doc.qt.io/qt-5/model-view-programming.html#model-subclassing-reference
     """
 
     def __init__(self, channels: List[ChannelConfig]):
-        """ Mutates `channels` and `line_color` for convenience. """
+        """Mutates `channels` and `line_color` for convenience."""
         super().__init__()
         self.channels = channels
 
