@@ -1,4 +1,6 @@
 import os
+import platform
+import struct
 import sys
 from pathlib import Path
 
@@ -7,7 +9,7 @@ _package = Path(__file__).parent
 
 
 # Version prefix
-base_version = "0.7.0"
+base_version = "0.7.1"
 is_dev = "-" in base_version
 
 
@@ -25,7 +27,7 @@ metadata_key = "build_metadata"
 
 
 def get_version() -> str:
-    """ Called at runtime (maybe pyinstaller time too).
+    """Called at runtime (maybe pyinstaller time too).
     Depends on pyinstaller_write_version and filesystem.
     """
     is_installer = hasattr(sys, "frozen")
@@ -41,7 +43,7 @@ def get_version() -> str:
 
 
 def pyinstaller_write_version() -> str:
-    """ Returns version.
+    """Returns version.
 
     Called only at pyinstaller time.
     Writes to filesystem, does NOT call get_version().
@@ -54,6 +56,15 @@ def pyinstaller_write_version() -> str:
         build_metadata = ""
         version = base_version
 
+    os = platform.system().lower()
+    if os == "windows":
+        os = "win"
+
+    # 32 or 64 bit
+    arch = str(struct.calcsize("P") * 8)
+
+    version = f"{version}-{os}{arch}"
+
     with version_txt.open("w") as txt:
         txt.write(version)
 
